==> tomee-project-8.0.6-source-release.zip: tomee-project-8.0.6/container/openejb-core/src/test/java/org/apache/openejb/core/cmp/jpa/Bill.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.core.cmp.jpa;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.IdClass;
import javax.persistence.Table;

@Entity
@Table(name = "bill")
@IdClass(BillPk.class)
public class Bill implements java.io.Serializable {
    private static final long serialVersionUID = 1L;

    private long billNumber;
    private long billVersion;
    private long billRevision;
    private String billDescription;

    @Id
    public long getBillNumber() {
        return billNumber;
    }

    public void setBillNumber(final long number) {
        billNumber = number;
    }

    @Id
    public long getBillVersion() {
        return billVersion;
    }

    public void setBillVersion(final long version) {
        billVersion = version;
    }

    @Id
    public long getBillRevision() {
        return billRevision;
    }

    public void setBillRevision(final long revision) {
        billRevision = revision;
    }

    public String getBillDescription() {
        return billDescription;
    }

    public void setBillDescription(final String description) {
        billDescription = description;
    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/container/openejb-core/src/test/java/org/apache/openejb/core/cmp/jpa/Bill.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.core.cmp.jpa;

import jakarta.persistence.Entity;
import jakarta.persistence.Id;
import jakarta.persistence.IdClass;
import jakarta.persistence.Table;

@Entity
@Table(name = "bill")
@IdClass(BillPk.class)
public class Bill implements java.io.Serializable {
    private static final long serialVersionUID = 1L;

    private long billNumber;
    private long billVersion;
    private long billRevision;
    private String billDescription;

    @Id
    public long getBillNumber() {
        return billNumber;
    }

    public void setBillNumber(final long number) {
        billNumber = number;
    }

    @Id
    public long getBillVersion() {
        return billVersion;
    }

    public void setBillVersion(final long version) {
        billVersion = version;
    }

    @Id
    public long getBillRevision() {
        return billRevision;
    }

    public void setBillRevision(final long revision) {
        billRevision = revision;
    }

    public String getBillDescription() {
        return billDescription;
    }

    public void setBillDescription(final String description) {
        billDescription = description;
    }
}
